<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Pago WebPay</title>
</head>
<body onload="submit()">
<form action="{{ url }}">
    <input type="hidden" name="token_ws" value="{{ token }}" />
</form>
<script>
    var submit = function () {
       var forms = document.getElementsByTagName('form');
       forms[0].submit();
    };
</script>
</body>
</html>