{% extends "checkout/preview.html" %}
{% load i18n %}
{% load static %}

{% block place_order %}
{% comment %}
Overwrite this template at will in roder to met your site's requirements.
{% endcomment%}
<form method="post" action="{% url 'webpay-place-order' %}" id="place_order_form">
    {% csrf_token %}
    {{ block.super }}
    {% block hiddenforms %}
        {{ block.super }}
        <input type="hidden" name="token_ws" value="{{ token_ws }}" />
        <input type='hidden' name='wsb_currency_id' value="{{ currency }}">
    {% endblock %}
</form>
{% endblock %}